..
    Copyright (C) 2024 CERN.

    Invenio-Preservation-Sync is free software; you can redistribute it
    and/or modify it under the terms of the MIT License; see LICENSE file for
    more details.


API Docs
========

Receivers
---------

.. automodule:: invenio_preservation_sync.receivers
   :members:

Resources
---------

.. automodule:: invenio_preservation_sync.resources.resource
    :members:
